@@ -14,10 +14,21 @@ from qtpy.QtCore import QPointF as PointF
 from qtpy.QtCore import QSizeF as SizeF
 from qtpy.QtCore import QRect as Rect
 from qtpy.QtCore import QRectF as RectF
-
+from .line import Line
+from .linef import LineF
+from .easingcurve import EasingCurve
+from prettyqt import core
 from .object import Object
+from .abstractanimation import AbstractAnimation
+from .animationgroup import AnimationGroup
+from .parallelanimationgroup import ParallelAnimationGroup
+from .variantanimation import VariantAnimation
+from .propertyanimation import PropertyAnimation
+from .versionnumber import VersionNumber
 from .datastream import DataStream
+from .bytearray import ByteArray
 from .url import Url
+from .urlquery import UrlQuery
 from .coreapplication import CoreApplication
 from .iodevice import IODevice
 from .filedevice import FileDevice
@@ -54,14 +65,22 @@ from .diriterator import DirIterator
 from .abstractitemmodel import AbstractItemModel
 from .abstractproxymodel import AbstractProxyModel
 from .abstractlistmodel import AbstractListModel
+from .stringlistmodel import StringListModel
 from .sortfilterproxymodel import SortFilterProxyModel
 from .abstracttablemodel import AbstractTableModel
 from .standardpaths import StandardPaths
 
+if core.VersionNumber.get_qt_version() >= (5, 13, 0):
+    from .concatenatetablesproxymodel import ConcatenateTablesProxyModel
+    from .transposeproxymodel import TransposeProxyModel
+
 __all__ = [
     "Object",
     "DataStream",
+    "VersionNumber",
+    "ByteArray",
     "Url",
+    "UrlQuery",
     "CoreApplication",
     "IODevice",
     "FileDevice",
@@ -74,6 +93,14 @@ __all__ = [
     "SizeF",
     "Point",
     "PointF",
+    "Line",
+    "LineF",
+    "EasingCurve",
+    "AbstractAnimation",
+    "AnimationGroup",
+    "ParallelAnimationGroup",
+    "VariantAnimation",
+    "PropertyAnimation",
     "Timer",
     "Translator",
     "Thread",
@@ -97,7 +124,10 @@ __all__ = [
     "AbstractItemModel",
     "AbstractProxyModel",
     "AbstractListModel",
+    "StringListModel",
     "SortFilterProxyModel",
+    "ConcatenateTablesProxyModel",
+    "TransposeProxyModel",
     "AbstractTableModel",
     "StandardPaths",
 ]
