@@ -7,6 +7,8 @@ import itertools
 
 from qtpy import QtCore, QtWidgets
 
+from prettyqt import core
+
 counter_dict: DefaultDict = defaultdict(itertools.count)
 
 
@@ -86,6 +88,45 @@ class Object(QtCore.QObject):
             flag = QtCore.Qt.FindDirectChildrenOnly
         return self.findChild(typ, name, options=flag)
 
+    def store_widget_states(self, settings=None, key: str = "states"):
+        splitters = self.find_children(QtWidgets.QSplitter)
+        splitter_dct = {
+            sp.objectName(): sp.saveState() for sp in splitters if sp.objectName()
+        }
+        mainwindows = self.find_children(QtWidgets.QMainWindow)
+        mw_dct = {
+            mw.objectName(): mw.saveState() for mw in mainwindows if mw.objectName()
+        }
+        headerviews = self.find_children(QtWidgets.QHeaderView)
+        headerview_dct = {
+            h.objectName(): h.saveState() for h in headerviews if h.objectName()
+        }
+        settings = core.Settings() if settings is None else settings
+        settings[key] = dict(
+            splitters=splitter_dct, mainwindows=mw_dct, headerviews=headerview_dct
+        )
+
+    def restore_widget_states(self, settings=None, key: str = "states"):
+        settings = core.Settings() if settings is None else settings
+        splitters = settings[key].get("splitters")
+        mainwindows = settings[key].get("splitters")
+        headerviews = settings[key].get("headerviews")
+        if splitters is not None:
+            for k, v in splitters.items():
+                w = self.find_child(QtWidgets.QSplitter, name=k)
+                if w is not None:
+                    w.restoreState(v)
+        if mainwindows is not None:
+            for k, v in mainwindows.items():
+                w = self.find_child(QtWidgets.QMainWindow, name=k)
+                if w is not None:
+                    w.restoreState(v)
+        if headerviews is not None:
+            for k, v in headerviews.items():
+                w = self.find_child(QtWidgets.QHeaderView, name=k)
+                if w is not None:
+                    w.restoreState(v)
+
     def find_parent(
         self, typ: QtCore.QObject, name: Optional[str] = None
     ) -> Optional[QtCore.QObject]:
