@@ -9,5 +9,11 @@ Contains custom models
 from .selectionmixin import SelectionMixin
 from .transposeproxymodel import TransposeProxyModel
 from .regexmatchesmodel import RegexMatchesModel
+from .columnitemmodel import ColumnItemModel
 
-__all__ = ["SelectionMixin", "TransposeProxyModel", "RegexMatchesModel"]
+__all__ = [
+    "SelectionMixin",
+    "TransposeProxyModel",
+    "RegexMatchesModel",
+    "ColumnItemModel",
+]
