@@ -12,12 +12,11 @@ def create_dot_pixmap(color="red", size=16):
     px = gui.Pixmap(size, size)
     px.fill(QtCore.Qt.transparent)
     px_size = px.rect().adjusted(1, 1, -1, -1)
-    painter = gui.Painter(px)
-    painter.setRenderHint(QtGui.QPainter.Antialiasing)
-    painter.setBrush(col)
-    painter.setPen(gui.Pen(gui.Color(15, 15, 15), 1.25))
-    painter.drawEllipse(px_size)
-    painter.end()
+    with gui.Painter(px) as painter:
+        painter.setRenderHint(QtGui.QPainter.Antialiasing)
+        painter.setBrush(col)
+        painter.setPen(gui.Pen(gui.Color(15, 15, 15), 1.25))
+        painter.drawEllipse(px_size)
     return px
 
 
@@ -45,7 +44,7 @@ class SidebarWidget(widgets.MainWindow):
         self.sidebar.set_icon_size(60)
         if show_settings:
             self.settings_btn = self.sidebar.add_menu_button(
-                "", icon="mdi.settings", menu=self.settings_menu
+                "", icon="mdi.wrench", menu=self.settings_menu
             )
             self.settings_btn.setFixedWidth(self.BUTTON_WIDTH)
             self.settings_btn.setFixedHeight(self.SETTINGS_BUTTON_HEIGHT)
