@@ -12,6 +12,7 @@ from qtpy.QtGui import QActionEvent as ActionEvent
 from qtpy.QtGui import QShowEvent as ShowEvent
 from qtpy.QtGui import QContextMenuEvent as ContextMenuEvent
 
+from .keysequence import KeySequence
 from .icon import Icon
 from .guiapplication import GuiApplication
 from .validator import Validator
@@ -23,24 +24,38 @@ except AttributeError:
     from .regularexpressionvalidator_pyside import (  # type: ignore
         RegularExpressionValidator,
     )
+from .textoption import TextOption
+from .textblock import TextBlock
+from .textdocument import TextDocument
 from .intvalidator import IntValidator
 from .doublevalidator import DoubleValidator
 from .brush import Brush
 from .textblockuserdata import TextBlockUserData
 from .color import Color
+from .gradient import Gradient
+from .lineargradient import LinearGradient
+from .radialgradient import RadialGradient
+from .conicalgradient import ConicalGradient
+from .pagesize import PageSize
+from .pagelayout import PageLayout
 from .font import Font
 from .fontmetrics import FontMetrics
+from .fontinfo import FontInfo
 from .fontdatabase import FontDatabase
 from .region import Region
+from .movie import Movie
 from .paintdevice import PaintDevice
+from .transform import Transform
 from .pagedpaintdevice import PagedPaintDevice
 from .image import Image
 from .pen import Pen
 from .picture import Picture
 from .pixmap import Pixmap
 from .painter import Painter
+from .painterpath import PainterPath
 from .palette import Palette
 from .cursor import Cursor
+from .polygon import Polygon
 from .polygonf import PolygonF
 from .standarditem import StandardItem
 from .standarditemmodel import StandardItemModel
@@ -48,7 +63,6 @@ from .textcharformat import TextCharFormat
 from .textcursor import TextCursor
 from .syntaxhighlighter import SyntaxHighlighter
 from .pdfwriter import PdfWriter
-from .keysequence import KeySequence
 from .desktopservices import DesktopServices
 
 
@@ -59,9 +73,18 @@ __all__ = [
     "ActionEvent",
     "ShowEvent",
     "ContextMenuEvent",
+    "Gradient",
+    "LinearGradient",
+    "RadialGradient",
+    "ConicalGradient",
+    "PageSize",
+    "PageLayout",
     "GuiApplication",
     "Validator",
     "RegExpValidator",
+    "TextOption",
+    "TextBlock",
+    "TextDocument",
     "RegularExpressionValidator",
     "IntValidator",
     "DoubleValidator",
@@ -70,9 +93,12 @@ __all__ = [
     "Color",
     "Font",
     "FontMetrics",
+    "FontInfo",
     "FontDatabase",
     "Region",
+    "Movie",
     "PaintDevice",
+    "Transform",
     "PagedPaintDevice",
     "Icon",
     "Image",
@@ -80,8 +106,10 @@ __all__ = [
     "Picture",
     "Pixmap",
     "Painter",
+    "PainterPath",
     "Palette",
     "Cursor",
+    "Polygon",
     "PolygonF",
     "StandardItem",
     "StandardItemModel",
