@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from typing import Tuple
 
 from qtpy import QtGui
 
@@ -16,6 +16,12 @@ class Image(QtGui.QImage):
         self.__init__()
         core.DataStream.write_bytearray(ba, self)
 
+    def __setitem__(self, index: Tuple[int, int], value):
+        self.setPixel(index[0], index[1], value)
+
+    def __getitem__(self, index: Tuple[int, int]):
+        return self.pixel(index[0], index[1])
+
 
 if __name__ == "__main__":
     image = Image()
