@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from typing import List
-import warnings
+from typing import Dict, Any, List
 import functools
 import sys
 import operator
@@ -16,25 +15,21 @@ def merge_flags(flags, mapping):
     return functools.reduce(operator.ior, [mapping[t] for t in flags])
 
 
-def deprecated(func):
-    """A decorator which can be used to mark functions as deprecated.
+def format_kwargs(kwargs: Dict[str, Any]) -> str:
+    kwarg_list = [f"{k}={repr(v)}" for k, v in kwargs.items()]
+    return ", ".join(kwarg_list)
 
-    It will result in a warning being emitted
-    when the function is used.
+
+def cut_off_str(obj, max_len: int):
+    """Create a string representation of an object, no longer than max_len characters.
+
+    Uses repr(obj) to create the string representation. If this is longer than max_len -3
+    characters, the last three will be replaced with elipsis.
     """
-
-    @functools.wraps(func)
-    def new_func(*args, **kwargs):
-        warnings.simplefilter("always", DeprecationWarning)  # turn off filter
-        warnings.warn(
-            "Call to deprecated function {}.".format(func.__name__),
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
-        warnings.simplefilter("default", DeprecationWarning)  # reset filter
-        return func(*args, **kwargs)
-
-    return new_func
+    s = repr(obj)
+    if len(s) > max_len - 3:
+        s = s[: max_len - 3] + "..."
+    return s
 
 
 def is_dark_mode() -> bool:
