@@ -5,7 +5,7 @@ from typing import Optional
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, gui
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import bidict, InvalidParamError, helpers, prettyprinter
 
 
 PRIORITIES = bidict(
@@ -34,7 +34,7 @@ ROLES = bidict(
 QtWidgets.QAction.__bases__ = (core.Object,)
 
 
-class Action(QtWidgets.QAction):
+class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
     def __init__(
         self,
         parent=None,
@@ -43,6 +43,7 @@ class Action(QtWidgets.QAction):
         shortcut: Optional[str] = None,
         tooltip: str = "",
         checkable: bool = False,
+        checked: bool = False,
         statustip: str = "",
         enabled: bool = True,
     ):
@@ -52,9 +53,14 @@ class Action(QtWidgets.QAction):
         self.set_shortcut(shortcut)
         self.set_tooltip(tooltip)
         self.set_checkable(checkable)
+        self.set_checked(checked)
         self.set_statustip(statustip)
         self.set_enabled(enabled)
 
+    def __repr__(self) -> str:
+        cls_name = self.__class__.__name__
+        return f"{cls_name}({helpers.format_kwargs(self.serialize_fields())})"
+
     def serialize_fields(self):
         return dict(
             auto_repeat=self.autoRepeat(),
@@ -62,7 +68,7 @@ class Action(QtWidgets.QAction):
             enabled=self.isEnabled(),
             visible=self.isVisible(),
             font=gui.Font(self.font()),
-            shortcut=self.shortcut(),
+            shortcut=self.get_shortcut(),
             tool_tip=self.toolTip(),
             checkable=self.isCheckable(),
             checked=self.isChecked(),
@@ -75,6 +81,7 @@ class Action(QtWidgets.QAction):
             shortcut_context=self.get_shortcut_context(),
             status_tip=self.statusTip(),
             whats_this=self.whatsThis(),
+            menu=self.menu(),
         )
 
     def __setstate__(self, state):
@@ -123,6 +130,12 @@ class Action(QtWidgets.QAction):
         if shortcut:
             self.setShortcut(shortcut)
 
+    def get_shortcut(self) -> Optional[gui.KeySequence]:
+        shortcut = gui.KeySequence(self.shortcut())
+        if not shortcut:
+            return None
+        return shortcut
+
     def set_menu(self, menu):
         self.setMenu(menu)
 
