@@ -1,20 +1,28 @@
 # -*- coding: utf-8 -*-
 
 import pathlib
-from typing import Optional
+from typing import Optional, Union
 import logging
 
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, gui, widgets
-from prettyqt.utils import colors
+from prettyqt.utils import colors, InvalidParamError
 
 logger = logging.getLogger(__name__)
 
+STANDARD_PIXMAPS = widgets.style.STANDARD_PIXMAPS
+
 QtWidgets.QApplication.__bases__ = (gui.GuiApplication,)
 
 
 class Application(QtWidgets.QApplication):
+    def __class_getitem__(cls, name: str) -> QtWidgets.QWidget:
+        widget = cls.get_widget(name)
+        if widget is None:
+            raise ValueError(f"Widget {name!r} does not exist.")
+        return widget
+
     def set_icon(self, icon: gui.icon.IconType):
         """Set the default window icon.
 
@@ -24,9 +32,12 @@ class Application(QtWidgets.QApplication):
         icon = gui.icon.get_icon(icon, color=colors.WINDOW_ICON_COLOR)
         self.setWindowIcon(icon)
 
-    def load_language_file(self, path: pathlib.Path):
+    def load_language_file(self, file: Union[pathlib.Path, str]):
         translator = core.Translator(self)
-        translator.load(str(path))
+        if file in ["de", "fr"]:
+            path = pathlib.Path(__file__).parent.parent
+            file = path / "localization" / f"qtbase_{file}.ts"
+        translator.load(str(file))
         self.installTranslator(translator)
 
     def set_metadata(
@@ -96,3 +107,17 @@ class Application(QtWidgets.QApplication):
         #     if isinstance(widget, QtWidgets.QWidget) and widget.objectName() == name:
         #         return widget
         # return None
+
+    @classmethod
+    def get_icon(cls, icon: str):
+        style = cls.style()
+        # icon_size = style.pixelMetric(QtWidgets.QStyle.PM_MessageBoxIconSize)
+        if icon not in STANDARD_PIXMAPS:
+            raise InvalidParamError(icon, STANDARD_PIXMAPS)
+        icon = style.standardIcon(STANDARD_PIXMAPS[icon])
+        return gui.Icon(icon)
+
+
+if __name__ == "__main__":
+    app = Application([])
+    app.load_language_file("de")
