@@ -3,10 +3,11 @@
 import functools
 from typing import Iterable, Optional, Union, List
 
+from deprecated import deprecated
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import core, widgets
-from prettyqt.utils import bidict, helpers, InvalidParamError
+from prettyqt.utils import bidict, InvalidParamError
 
 
 ORIENTATIONS = bidict(horizontal=QtCore.Qt.Horizontal, vertical=QtCore.Qt.Vertical)
@@ -36,20 +37,28 @@ class HeaderView(QtWidgets.QHeaderView):
         self.setSectionsClickable(True)
         self._widget_name = parent.id if parent is not None else ""
 
-    def save_state(self):
-        settings = core.Settings()
-        settings.setValue(f"{self._widget_name}.state", self.saveState())
+    def save_state(
+        self, settings: Optional[core.Settings] = None, key: Optional[str] = None
+    ):
+        settings = core.Settings() if settings is None else settings
+        key = f"{self._widget_name}.state" if key is None else key
+        settings.set_value(key, self.saveState())
 
-    def load_state(self):
-        settings = core.Settings()
-        state = settings.get(f"{self._widget_name}.state", None)
+    def load_state(
+        self, settings: Optional[core.Settings] = None, key: Optional[str] = None
+    ) -> bool:
+        settings = core.Settings() if settings is None else settings
+        key = f"{self._widget_name}.state" if key is None else key
+        state = settings.get(key, None)
         if state is not None:
             self.restoreState(state)
+            return True
+        return False
 
     def resize_sections(self, mode: str):
         self.resizeSections(MODES[mode])
 
-    @helpers.deprecated
+    @deprecated(reason="This method is deprecated, use set_resize_mode instead.")
     def resize_mode(self, mode: str, col: Optional[int] = None):
         self.set_resize_mode(mode, col)
 
@@ -61,7 +70,7 @@ class HeaderView(QtWidgets.QHeaderView):
         else:
             self.setSectionResizeMode(col, MODES[mode])
 
-    def section_labels(self) -> List[str]:
+    def get_section_labels(self) -> List[str]:
         model = self.model()
         return [
             model.headerData(i, QtCore.Qt.Horizontal, QtCore.Qt.DisplayRole)
@@ -71,15 +80,21 @@ class HeaderView(QtWidgets.QHeaderView):
     def contextMenuEvent(self, event):
         """Context menu for our files tree."""
         menu = widgets.Menu(parent=self)
-        for i, header_label in enumerate(self.section_labels()[1:], start=1):
-            act = menu.addAction(header_label)
-            act.setCheckable(True)
-            val = not self.isSectionHidden(i)
-            act.setChecked(val)
-            fn = functools.partial(self.set_section_hidden, i=i, hide=val)
-            act.triggered.connect(fn)
+        actions = self.get_header_actions()
+        menu.add_actions(actions)
         menu.exec_(self.mapToGlobal(event.pos()))
 
+    def get_header_actions(self) -> List[widgets.Action]:
+        actions = list()
+        labels = self.get_section_labels()[1:]
+        for i, header_label in enumerate(labels, start=1):
+            val = not self.isSectionHidden(i)
+            action = widgets.Action(text=header_label, checkable=True, checked=val)
+            fn = functools.partial(self.set_section_hidden, i=i, hide=val)
+            action.triggered.connect(fn)
+            actions.append(action)
+        return actions
+
     def set_section_hidden(self, i: int, hide: bool):
         self.section_vis_changed.emit(i, hide)
         self.setSectionHidden(i, hide)
