@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 
+import sys
+import traceback
 from typing import Optional, List
 
 from qtpy import QtCore, QtWidgets
 
-from prettyqt import gui, widgets
+from prettyqt import gui, widgets, core
 from prettyqt.utils import bidict, InvalidParamError
 
 
@@ -41,7 +43,8 @@ BUTTONS = bidict(
 TEXT_FORMATS = bidict(
     rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
 )
-
+if core.VersionNumber.get_qt_version() >= (5, 14, 0):
+    TEXT_FORMATS["markdown"] = QtCore.Qt.MarkdownText
 
 QtWidgets.QMessageBox.__bases__ = (widgets.BaseDialog,)
 
@@ -52,6 +55,7 @@ class MessageBox(QtWidgets.QMessageBox):
         icon: gui.icon.IconType = None,
         title: Optional[str] = None,
         text: str = "",
+        informative_text: str = "",
         details: str = "",
         buttons: Optional[list] = None,
         parent: Optional[QtWidgets.QWidget] = None,
@@ -59,6 +63,7 @@ class MessageBox(QtWidgets.QMessageBox):
         super().__init__(parent)
         self.set_icon(icon)
         self.setText(text)
+        self.setInformativeText(informative_text)
         self.setWindowTitle(title)
         self.setWindowFlags(
             QtCore.Qt.Dialog | QtCore.Qt.WindowTitleHint | QtCore.Qt.CustomizeWindowHint
@@ -82,6 +87,13 @@ class MessageBox(QtWidgets.QMessageBox):
             m.setDetailedText(detail_text)
         return m.show_blocking()
 
+    @classmethod
+    def show_exception(cls, exception: Exception):
+        exctype, value = sys.exc_info()[:2]
+        tb = traceback.format_exc()
+        dlg = cls(text=str(value), title=str(exctype), icon="critical", details=tb)
+        dlg.show_blocking()
+
     def set_icon(self, icon: gui.icon.IconType):
         if icon in ICONS:
             self.setIcon(ICONS[icon])
