@@ -5,13 +5,19 @@ from typing import Union, Optional, Dict
 from qtpy import QtCore, QtGui, QtWidgets
 
 from prettyqt import core, gui, widgets
-from prettyqt.utils import bidict, InvalidParamError
+from prettyqt.utils import bidict, InvalidParamError, autoslot
 
 
 TAB_SHAPES = bidict(
     rounded=QtWidgets.QTabWidget.Rounded, triangular=QtWidgets.QTabWidget.Triangular
 )
 
+TAB_POSITIONS = bidict(
+    north=QtWidgets.QTabWidget.North,
+    south=QtWidgets.QTabWidget.South,
+    west=QtWidgets.QTabWidget.West,
+    east=QtWidgets.QTabWidget.East,
+)
 
 QtWidgets.QTabWidget.__bases__ = (widgets.Widget,)
 
@@ -59,6 +65,7 @@ class TabWidget(QtWidgets.QTabWidget):
             tab_shape=self.get_tab_shape(),
             # elide_mode=self.get_elide_mode(),
             icon_size=self.iconSize(),
+            tab_position=self.get_tab_position(),
         )
 
     def __setstate__(self, state):
@@ -95,13 +102,38 @@ class TabWidget(QtWidgets.QTabWidget):
     def get_tab_shape(self) -> str:
         """Return tab shape.
 
-        possible values are "roundes", "triangular"
+        possible values are "rounded", "triangular"
 
         Returns:
             tab shape
         """
         return TAB_SHAPES.inv[self.tabShape()]
 
+    def set_tab_position(self, position: str) -> None:
+        """Set tab position for the tabwidget.
+
+        Valid values are "north", "south", "east", "west"
+
+        Args:
+            position: tab position to use
+
+        Raises:
+            InvalidParamError: tab position does not exist
+        """
+        if position not in TAB_POSITIONS:
+            raise InvalidParamError(position, TAB_POSITIONS)
+        self.setTabPosition(TAB_POSITIONS[position])
+
+    def get_tab_position(self) -> str:
+        """Return tab position.
+
+        possible values are "north", "south", "east", "west"
+
+        Returns:
+            tab position
+        """
+        return TAB_POSITIONS.inv[self.tabPosition()]
+
     def get_children(self) -> list:
         return [
             (
@@ -125,7 +157,7 @@ class TabWidget(QtWidgets.QTabWidget):
     def set_closable(self, closable: bool = True) -> None:
         self.setTabsClosable(closable)
 
-    @core.Slot(int, QtCore.QPoint)
+    @autoslot.AutoSlot
     def detach_tab(self, index: int, point: QtCore.QPoint) -> None:
         """Detach tab by removing its contents and placing them in a DetachedTab window.
 
@@ -219,14 +251,14 @@ class TabWidget(QtWidgets.QTabWidget):
         for tab in tabs:
             tab.close()
 
-    @core.Slot(int)
+    @autoslot.AutoSlot
     def remove_tab(self, index: int) -> None:
         widget = self.widget(index)
         self.removeTab(index)
         if widget is not None:
             widget.deleteLater()
 
-    @core.Slot(object, str)
+    @autoslot.AutoSlot
     def open_widget(self, widget: QtWidgets.QWidget, title: str = "Unnamed"):
         """Create a tab containing delivered widget."""
         self.add_tab(widget, title, icon="mdi.widgets", show=True)
