@@ -3,7 +3,7 @@
 from qtpy import QtCore, QtWidgets
 
 from prettyqt import gui, core
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, InvalidParamError
 
 
 STATES = bidict(
@@ -21,8 +21,8 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
         icon = self.icon(0)
         return dict(
             text=self.text(0),
-            tooltip=self.toolTip(0),
-            statustip=self.statusTip(0),
+            tool_tip=self.toolTip(0),
+            status_tip=self.statusTip(0),
             checkstate=self.get_checkstate(),
             icon=gui.Icon(icon) if not icon.isNull() else None,
             data=self.data(0, QtCore.Qt.UserRole),
@@ -53,10 +53,10 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
             state: checkstate to use
 
         Raises:
-            ValueError: invalid checkstate
+            InvalidParamError: invalid checkstate
         """
         if state not in STATES:
-            raise ValueError("Invalid checkstate.")
+            raise InvalidParamError(state, STATES)
         self.setCheckState(0, STATES[state])
 
     def get_checkstate(self) -> str:
